@@ -733,6 +733,39 @@ class Connection:
         config = utils.parse_json_response(response)
         return config
 
+    def get_config_history(self, entity_id, since=None, limit=None, reverse=None):
+        """Returns the history of the configuration entity of the sesam node.
+
+        :param entity_id: the id of the entity
+
+        :param since: The opaque value that can be used to efficiently skip already seen entities.
+
+        :param limit: The "limit" parameter specifies the maximum number of entities to return.
+                      If this is not specified, all available entities are returned.
+
+        :param reverse: If this is False (the default) entities will returned with the oldest entity first. \
+                        If this is True, the newest entity will be returned first.
+        """
+
+        url = self.sesamapi_base_url + "config-history/entity"
+
+        request_params = {"entity_id": entity_id}
+
+        if since is not None:
+            request_params["since"] = since
+
+        if limit is not None:
+            request_params["limit"] = limit
+
+        if reverse and reverse is True:
+            request_params["reverse"] = reverse
+
+        response = self.do_get_request(url, allowable_response_status_codes=[200], params=request_params)
+        utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/json")
+        config = utils.parse_json_response(response)
+
+        return config
+
     def get_config_as_json_string(self, config_group=None):
         """Returns the configuration of the sesam node as a json-string, using the same formatting
         as the raw server response.
